# frozen_string_literal: true

gemspecs = FileList.new('**/*.gemspec')

if gemspecs.size > 1
  require 'rake/clean'
  require 'bundler/gem_helper'
  CLOBBER.include 'pkg'

  gems = gemspecs.sub(/\.gemspec$/, '')

  gems.each do |gem_name|
    namespace gem_name do
      Bundler::GemHelper.install_tasks(name: gem_name)
    end
  end

  namespace :gem do
    desc 'Build each gem'
    task build: gems.map { |gem| :"#{gem}:build" }

    desc 'Install each gem'
    task install: gems.map { |gem| :"#{gem}:install" }

    namespace :install do
      desc 'Install each gem without network access'
      task local: gems.map { |gem| :"#{gem}:install" }
    end

    desc "Create tags, build and push each gem to Rubygems\n" \
           'To prevent publishing in Rubygems use `gem_push=no rake release`'
    task 'release', [:remote] => gems.map { |gem| :"#{gem}:release" }

    desc 'List all gems'
    task :list do
      gems.each { |gem| puts gem }
    end
  end

  namespace :build do
    task default: %i[gem:build]
  end
elsif gemspecs.size == 1
  require 'bundler/gem_tasks'
end
